@@ -62,7 +62,8 @@ c         exam models
 c
       if( index(IntModel, 'fritiof1.6') .gt. 0 .or.
      *    index(IntModel, 'nucrin') .gt. 0  .or.
-     *    index(IntModel, 'dpmjet3') .gt. 0 ) then
+     *    index(IntModel, 'dpmjet3') .gt. 0  .or.
+     *    index(IntModel, 'incdpm3') .gt. 0  ) then
 c           for Lund init.  dpm may use Lund at low energy or
 c                                    for some particles
          call haddenC
@@ -76,7 +77,7 @@ c         Gheisha; init. Gheisha cannot use hadrin/nucrin in Cosmos
          call gpart
          call gheini
       endif
-      if( index(IntModel, 'dpmjet3') .gt. 0) then
+      if( index(IntModel, 'dpmjet3') .gt. 0 ) then
          if(from .eq. 'cosmos') then
             ! init for dpmjet.  for Cosmos
             ! If DpmFile is ' ',
