@@ -3,9 +3,9 @@ c         earth defining parameter
      *        Eecen2,      !  squared of the ecentricity 
      *        Eone_ecen2,  !  1 - ecen2
      *        Maxheight,   !  max height with some air. m
-     *        Minheight,   !  min height without soil. m   
-     *	      Maxnodes     !  max number of nodes to express atmospher
+     *        Minheight    !  min height without soil. m   
+
 c
        parameter (Eradius = 6378136.0d0, Eecen2= 0.006694470d0,
      *       Eone_ecen2 = 1.d0 - Eecen2, Maxheight=220.d3, 
-     *       Minheight = -500.d0, Maxnodes=20)     		  
+     *       Minheight = -500.d0)
