@@ -49,7 +49,7 @@ c                 save the initial seed of random number
             call cpush(incident)
             call cforceSSP
          endif
-
+         call csetMolUnit
          call chookBgEvent    ! user hook for each event beginning
 
          call ctrackingAll
@@ -61,6 +61,28 @@ c              next is managed by chookEnEven if new flesh
 
       enddo
  10   continue
+      end
+      subroutine  csetMolUnit
+#include "Ztrack.h"
+#include "Zobs.h"
+#include "Zobsp.h"
+#include "Zobsv.h"
+
+c         set  Moliere unit at each observtion depth (2r.l above along primary)
+      record /track/inci
+      record /coord/angle
+      integer i
+      real*8 mu
+      call cqIncident(inci, angle)
+
+      do  i = 1, NoOfSites
+         call cgetMoliereU(ObsSites(i).pos.depth, inci.vec.coszenith, 
+     *    ObsSites(i).mu)
+      enddo
+      do i = 1, NoOfASSites
+         call cgetMoliereU(ASObsSites(i).pos.depth, inci.vec.coszenith, 
+     *       ASObsSites(i).mu)
+      enddo
       end
       subroutine  cforceSSP
 #include "Ztrack.h"
