@@ -4,6 +4,13 @@ c     ****************************************************************
       subroutine cmanager
       implicit none
 #include "Zevhnp.h"
+
+c       *********************** for Inclusive init.
+       real*8  fact_cross, fac_alpha
+       common /crosssection_factor/fact_cross
+       common /he_factor/fac_alpha
+c       **********************
+                           
 c      
       call creadParam(5)        ! read execution conditions from stdin
 #ifdef NEXT486
@@ -12,6 +19,12 @@ c
      *  ' for NEXT-Absoft Fortran', 0)
       endif
 #endif
+c     ******************************
+      if(index(IntModel, 'incdpm3')  .gt. 0 ) then
+         fact_cross = 0.95
+         fac_alpha = 1.77       ! not used in Cosmos
+      endif                         
+c     **********************
       call cbeginRun            ! initialize the simulation
       call ceventLoop           ! begin simulation and enter  event Loop
       call cendRun              ! close the simulation
