@@ -28,9 +28,9 @@ c        m.f.p (kg/m**2) = abn /xsec(mb)
 c        parameter (aira=14.5, abogn=6.02e23, abn=aira*1.e28/abogn)
       real*8 abogn, toabn
       parameter (abogn=6.02d23, toabn=1.d28/abogn)
-      real*8 collkgram, u,length
+      real*8 collkgram, u,length, crossint
       real*8  eps/1.e-8/, smallxs/1.e-10/, largexs/1.e10/
-      integer ica, ka, subcode
+      integer ica, ka, subcode, kinc
       logical useInt2
       character*70 msg
 
@@ -104,6 +104,17 @@ c               sample interaction length
          call rndc(u)
 
          collkgram=-mfp*log(u)
+      elseif(ActiveMdl .eq. 'incdpm3'  .and. ek .gt. 0.1d0 .and.
+     *    ( ka .eq. knuc .or. ka .eq. kpion  .or. ka .eq. kkaon ) ) then
+c            special for inclusive treatment
+c         *********************************
+         call cccode2hcode(TrackBefMove.p, kinc)
+         xs = crossint(kinc, ek)
+         mfp = toabn*TargetMassN/xs ! in kg/m2
+c             sample interaction length
+         call rndc(u)
+         collkgram=-mfp*log(u)
+c         *******************************
       else
 c         get mean free path for collision
          if(ka .eq. kpion .or. ka .eq. keta) then
@@ -206,11 +217,6 @@ c             sample interaction length
       if(.not.Freec .and. Zfirst.pos.depth .eq.0.) then
          collkgram = 0.
       endif
-c/////////////////
-c      write(*,*) ' ActivM=',ActiveMdl, ' code=',ka,
-c     *        ' E=',ek, ' mfp=',mfp/10., ' Useint=',UseInt2
-c      write(*,*) ' colg=',collkgram/10.
-c////////////
       call csetIntInf(collkgram, .false., 'coll')
 c          knockon
  100  continue
@@ -227,6 +233,11 @@ c           knockon is treated in epics specially.
             endif
          endif
       endif
+c/////////////////
+c      write(*,*) ' ActivM=',ActiveMdl, ' code=',ka,
+c     *        ' E=',ek, ' mfp=',mfp/10., ' Useint=',UseInt2
+c      write(*,*) ' colg=',collkgram/10.,  'xs=', xs
+c////////////
       end
 
 
